HomeRunOutlierModel: Shiny App for Estimating Home Run Rate Trajectories

View source: R/HomeRunOutlierModel.R

HomeRunOutlierModelR Documentation

Shiny App for Estimating Home Run Rate Trajectories

Description

Shiny app to estimate the home run rate trajectories for a selected player using an outlier model.

Usage

  HomeRunOutlierModel()

Author(s)

Jim Albert


bayesball/ShinyBaseball documentation built on March 26, 2024, 9:26 a.m.