| HomeRunPeak | R Documentation |
Shiny app to estimate the home run rate trajectory of a selected player using a multilevel model.
HomeRunPeak()
Jim Albert
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.