HomeRunPrediction2: Shiny App to Illustrate Bayesian Prediction

View source: R/HomeRunPrediction2.R

HomeRunPrediction2R Documentation

Shiny App to Illustrate Bayesian Prediction

Description

Shiny app to illustrate Bayesian prediction of the number of home runs hit in the remainder of the season

Usage

  HomeRunPrediction2()

Author(s)

Jim Albert


bayesball/ShinyBaseball documentation built on March 26, 2024, 9:26 a.m.