| twentyyears_RE | R Documentation |
Runs expectancy calculations for the 2000-2019 seasons
twentyyears_RE
A data frame with 480 observations on the following 6 variables.
number of outs
runners on base
mean runs scored in remainder of inning
baseball season
probability of scoring in the remainder of the inning
probability of scoring 2 or more runs in the remainder of the inning
Retrosheet
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.