View source: R/HomeRunOutlierModel.R
| HomeRunOutlierModel | R Documentation |
Shiny app to estimate the home run rate trajectories for a selected player using an outlier model.
HomeRunOutlierModel()
Jim Albert
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.